@@ -88,7 +88,8 @@ def run_action(cmd_options, required_options, resource, action, callback):
 
     result = get_config()
     username, api_key = result['username'], result['api_key']
-    api_url, auth_url = result['api_url'], result['auth_url']
+    auth_token, api_url = result['auth_token'], result['api_url']
+    auth_url = result['auth_url']
     ssl_verify = result['ssl_verify']
 
     if options.username:
@@ -100,13 +101,17 @@ def run_action(cmd_options, required_options, resource, action, callback):
     if options.api_url:
         api_url = options.api_url
 
+    if options.auth_token:
+        auth_token = options.auth_token
+
     if options.auth_url:
         auth_url = options.auth_url
 
-    if not username or not api_key:
-        print('No username and API key provided!')
-        print('You need to either put credentials in ~/.raxrc or ' +
-              'pass them to the command using --username and --api-key option')
+    if (not username or not api_key) and (not auth_token or not api_url):
+        print('No username/API key or auth token/API URL provided!')
+        print('You need to either put credentials in ~/.raxrc or '
+              'pass them to the command using --username/--api-key '
+              'or --auth-token/--api-url options')
         sys.exit(1)
 
     if options.debug:
@@ -116,7 +121,7 @@ def run_action(cmd_options, required_options, resource, action, callback):
     if options.no_ssl_verify or ssl_verify == False:
         libcloud.security.VERIFY_SSL_CERT = False
 
-    instance = get_instance(username, api_key, api_url, auth_url)
+    instance = get_instance(username, api_key, api_url, auth_url, auth_token)
 
     if not getattr(options, 'who', None):
         options.who = username
@@ -127,12 +132,13 @@ def run_action(cmd_options, required_options, resource, action, callback):
         traceback.print_exc(file=sys.stderr)
 
 
-def get_instance(username, api_key, url, auth_url=None):
+def get_instance(username, api_key, url, auth_url=None, auth_token=None):
     driver = get_driver(Provider.RACKSPACE)
 
     kwargs = {}
     kwargs['ex_force_base_url'] = url
     kwargs['ex_force_auth_url'] = auth_url
+    kwargs['ex_force_auth_token'] = auth_token
     instance = driver(username, api_key, **kwargs)
 
     return instance
